@@ -1,6 +1,6 @@
 package FFI::Raw::MemPtr;
 {
-  $FFI::Raw::MemPtr::VERSION = '0.25';
+  $FFI::Raw::MemPtr::VERSION = '0.26';
 }
 
 use strict;
@@ -12,13 +12,16 @@ FFI::Raw::MemPtr - FFI::Raw memory pointer type
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 DESCRIPTION
 
 A B<FFI::Raw::MemPtr> represents a memory pointer which can be passed to
 functions taking a C<FFI::Raw::ptr> argument.
 
+The allocated memory is automatically deallocated once the object is not in use
+anymore.
+
 =head1 METHODS
 
 =head2 new( $length )
@@ -32,7 +35,7 @@ into it. This can be used, for example, to pass a pointer to a function that
 takes a C struct pointer, by using C<pack()> or the L<Convert::Binary::C> module
 to create the actual struct content.
 
-For example, consider a C function:
+For example, consider the following C code
 
     struct some_struct {
       int some_int;
@@ -69,7 +72,8 @@ This is the C<FFI::Raw> equivalent of a pointer to a pointer.
 
 =head2 tostr( [$length] )
 
-Convert a C<FFI::Raw::MemPtr> to a Perl string.
+Convert a C<FFI::Raw::MemPtr> to a Perl string. If C<$length> is not provided,
+the length of the string will be computed using C<strlen()>.
 
 =head1 AUTHOR
 
